@@ -23,7 +23,7 @@ import re, os
 
 
 # The current version of rdiff-backup
-version = "1.1.15"
+version = "1.1.16"
 
 # If this is set, use this value in seconds as the current time
 # instead of reading it from the clock.
@@ -47,9 +47,14 @@ server = None
 
 # uid and gid of the owner of the rdiff-backup process.  This can
 # vary depending on the connection.
-process_uid = os.getuid()
-process_gid = os.getgid()
-process_groups = [process_gid] + os.getgroups()
+try:
+	process_uid = os.getuid()
+	process_gid = os.getgid()
+	process_groups = [process_gid] + os.getgroups()
+except AttributeError:
+	process_uid = 0
+	process_gid = 0
+	process_groups = [0]
 
 # If true, when copying attributes, also change target's uid/gid
 change_ownership = None
